@@ -16,11 +16,13 @@ from apio import util
 from apio.resources import Resources
 from apio.managers.system import System
 from apio.managers.project import Project
+from apio.profile import Profile
 
 
 class SCons(object):
 
     def __init__(self):
+        self.profile = Profile()
         self.resources = Resources()
 
     def clean(self):
@@ -49,40 +51,26 @@ class SCons(object):
 
         # Get programmer value
         if board:
-            programmer = self.resources.boards[board]['prog']
+            p = self.resources.boards[board]['programmer']
+            programmer = p['type']
+            programmer_args = p['args'] if 'args' in p else ''
         else:
-            programmer = 'ftdi'  # Defaut value
+            programmer = 'iceprog'
+            programmer_args = ''
 
-        # -- Icoprog
-        if programmer == 'icoprog':
-            # Icoboard + RPI2,3
-            # Device argument is ignored
-            if device and device != -1:
-                click.secho(
-                    'Info: ignore device argument {0}'.format(device),
-                    fg='yellow')
-            # Check architecture
-            arch = self.resources.boards[board]['check']['arch']
-            current_arch = util.get_systype()
-            if arch != current_arch:
-                # Incorrect architecture
-                click.secho(
-                    'Error: incorrect architecture: RPI2 or RPI3 required',
-                    fg='red')
-                return 1
-
-        # -- FTDI USB
-        elif programmer == 'ftdi':
+        # -- Check
+        check = self.resources.boards[board]['check']
 
+        # Check FTDI description
+        if 'ftdi-desc' in check:
             detected_boards = System().detect_boards()
-
             if isinstance(detected_boards, int):
                 return detected_boards
 
             if device:
                 # Check device argument
                 if board:
-                    desc = self.resources.boards[board]['check']['ftdi-desc']
+                    desc = check['ftdi-desc']
                     check = False
                     for b in detected_boards:
                         # Selected board
@@ -101,7 +89,7 @@ class SCons(object):
                 # Detect device
                 device = -1
                 if board:
-                    desc = self.resources.boards[board]['check']['ftdi-desc']
+                    desc = check['ftdi-desc']
                     for b in detected_boards:
                         if desc in b['description']:
                             # Select the first board that validates
@@ -127,27 +115,32 @@ class SCons(object):
                 click.secho('Error: board not detected', fg='red')
                 return 1
 
-        # -- Litterbox
-        elif programmer == 'litterbox':
-            # Cat Board + RPI2,3
+        # Check architectures
+        if 'arch' in check:
             # Device argument is ignored
             if device and device != -1:
                 click.secho(
                     'Info: ignore device argument {0}'.format(device),
                     fg='yellow')
-            # Check architecture
-            arch = self.resources.boards[board]['check']['arch']
+
+            arch = check['arch']
             current_arch = util.get_systype()
             if arch != current_arch:
                 # Incorrect architecture
-                click.secho(
-                    'Error: incorrect architecture: RPI2 or RPI3 required',
-                    fg='red')
+                if arch == 'linux_armv7l':
+                    click.secho(
+                        'Error: incorrect architecture: RPI2 or RPI3 required',
+                        fg='red')
+                else:
+                    click.secho(
+                        'Error: incorrect architecture {0}'.format(arch),
+                        fg='red')
                 return 1
 
         return self.run('upload',
                         variables + ['device={0}'.format(device),
-                                     'prog={0}'.format(programmer)],
+                                     'prog={0}'.format(programmer),
+                                     'prog_args={0}'.format(programmer_args)],
                         board)
 
     def time(self, args):
@@ -167,42 +160,51 @@ class SCons(object):
         scons_dir = os.path.join(packages_dir, 'tool-scons', 'script')
         sconstruct_name = 'SConstruct'
 
-        # Give the priority to the packages installed by apio
-        os.environ['PATH'] = os.pathsep.join(
-            [iverilog_dir, icestorm_dir, os.environ['PATH']])
-
-        # Add environment variables
-        os.environ['IVL'] = os.path.join(
-            packages_dir, 'toolchain-iverilog', 'lib', 'ivl')
-        os.environ['VLIB'] = os.path.join(
-            packages_dir, 'toolchain-iverilog', 'vlib', 'system.v')
-
-        # -- Check for the scons
-        if not isdir(scons_dir):
-            click.secho('Error: scons toolchain is not installed', fg='red')
-            click.secho('Please run:\n'
-                        '   apio install scons', fg='yellow')
-
-        # -- Check for the icestorm tools
-        if not isdir(icestorm_dir):
-            click.secho('Error: icestorm toolchain is not installed', fg='red')
-            click.secho('Please run:\n'
-                        '   apio install icestorm', fg='yellow')
-
-        # -- Check for the iverilog tools
-        if not isdir(iverilog_dir):
-            click.secho('Error: iverilog toolchain is not installed', fg='red')
-            click.secho('Please run:\n'
-                        '   apio install iverilog', fg='yellow')
-
         # -- Check for the SConstruct file
         if not isfile(join(util.get_project_dir(), sconstruct_name)):
             click.secho('Using default SConstruct file')
             variables += ['-f', join(
                 dirname(__file__), '..', 'resources', sconstruct_name)]
 
+        if self.profile.check_exe_apio():
+
+            # Give the priority to the packages installed by apio
+            os.environ['PATH'] = os.pathsep.join(
+                [iverilog_dir, icestorm_dir, os.environ['PATH']])
+
+            # Add environment variables
+            os.environ['IVL'] = os.path.join(
+                packages_dir, 'toolchain-iverilog', 'lib', 'ivl')
+            os.environ['VLIB'] = os.path.join(
+                packages_dir, 'toolchain-iverilog', 'vlib', 'system.v')
+
+            # -- Check for the scons tools
+            if not isdir(scons_dir):
+                click.secho(
+                    'Error: scons toolchain is not installed', fg='red')
+                click.secho('Please run:\n'
+                            '   apio install scons', fg='yellow')
+
+            # -- Check for the icestorm tools
+            if not isdir(icestorm_dir):
+                click.secho(
+                    'Error: icestorm toolchain is not installed', fg='red')
+                click.secho('Please run:\n'
+                            '   apio install icestorm', fg='yellow')
+
+            # -- Check for the iverilog tools
+            if not isdir(iverilog_dir):
+                click.secho(
+                    'Error: iverilog toolchain is not installed', fg='red')
+                click.secho('Please run:\n'
+                            '   apio install iverilog', fg='yellow')
+
         # -- Execute scons
-        if isdir(scons_dir) and isdir(icestorm_dir) and isdir(iverilog_dir):
+        if not self.profile.check_exe_apio() or \
+           (isdir(scons_dir) and
+           isdir(icestorm_dir) and
+           isdir(iverilog_dir)):
+
             terminal_width, _ = click.get_terminal_size()
             start_time = time.time()
 
@@ -220,13 +222,15 @@ class SCons(object):
 
             click.secho("Executing: scons -Q {0} {1}".format(
                             command, ' '.join(variables)))
+
+            if self.profile.check_exe_apio():
+                scons = [os.path.normpath(sys.executable),
+                         os.path.join(scons_dir, 'scons')]
+            else:
+                scons = ['scons']
+
             result = util.exec_command(
-                [
-                    os.path.normpath(sys.executable),
-                    os.path.join(scons_dir, 'scons'),
-                    '-Q',
-                    command
-                ] + variables,
+                scons + ['-Q', command] + variables,
                 stdout=util.AsyncPipe(self._on_run_out),
                 stderr=util.AsyncPipe(self._on_run_err)
             )
